@@ -85,6 +85,7 @@ static void
 save_configuration(ConduitCfg *c) 
 {
 	gchar *prefix;
+        char buf[20];
 
 	g_assert(c!=NULL);
 
@@ -94,10 +95,10 @@ save_configuration(ConduitCfg *c)
 	gnome_config_set_string("dir", c->dir);
 	gnome_config_set_string("date_format", c->dateFormat);
 	gnome_config_set_int("output_format", c->outputFormat);
-	g_snprintf(prefix,255,"0%o", c->dirMode);
-	gnome_config_set_string("dir mode", prefix);
-	g_snprintf(prefix,255,"0%o", c->fileMode);
-	gnome_config_set_string("file mode", prefix);
+	g_snprintf(buf,sizeof(buf),"0%o", c->dirMode);
+	gnome_config_set_string("dir mode", buf);
+	g_snprintf(buf,sizeof(buf),"0%o", c->fileMode);
+	gnome_config_set_string("file mode", buf);
 
 	gnome_config_pop_prefix();
 
@@ -363,7 +364,7 @@ insert_ignore_space_cb (GtkEditable    *editable, const gchar    *text,
                         gint len, gint *position, void *data)
 {
         gint i;
-        gchar *curname;
+        const gchar *curname;
 
         curname = gtk_entry_get_text(GTK_ENTRY(editable));
         if (*curname == '\0' && len > 0) {
