@@ -59,10 +59,10 @@ void conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit);
 #define CONDUIT_VERSION "0.9"
 
 static void 
-load_configuration (ConduitCfg **c,guint32 pilotId) 
+load_configuration (GnomePilotConduit *conduit, ConduitCfg **c,guint32 pilotId) 
 {
 	char *prefix;
-	char *buf;
+	char *buf, *key;
 	g_return_if_fail (c!=NULL);
 	
 	prefix = g_strdup_printf (CONFIG_PREFIX, pilotId);
@@ -84,11 +84,21 @@ load_configuration (ConduitCfg **c,guint32 pilotId)
 	(*c)->secret_mode =(mode_t)strtol (buf, NULL, 0);
 	g_free (buf);
 
-	(*c)->dir = gnome_config_get_string ("dir=");
+	key = g_strdup_printf ("dir=%s/memo_file", gnome_pilot_conduit_get_base_dir (conduit));
+	(*c)->dir = gnome_config_get_string (key);
+	g_free (key);
 	
-	while ((*c)->dir[strlen ((*c)->dir)-1] == '/') {
+	while ((*c)->dir && strlen ((*c)->dir) > 0 && (*c)->dir[strlen ((*c)->dir)-1] == '/') {
 		(*c)->dir[strlen ((*c)->dir)-1] = '\0';
 	}
+
+	if(mkdir((*c)->dir, (*c)->dir_mode) < 0) { /* Wow, I never though I would
+							  use octal in C :) */
+		if(errno != EEXIST) {
+			g_free ((*c)->dir);
+			(*c)->dir = NULL;
+		}
+	}    
 	
 	(*c)->ignore_end=gnome_config_get_string ("ignore end");
 	(*c)->ignore_start=gnome_config_get_string ("ignore start");
@@ -454,7 +464,7 @@ backup_directory (GnomePilotConduitStandardAbs *abs)
 	strcpy (tmp, GET_CONDUIT_CFG (abs)->dir);
 	filename = g_strdup_printf ("%s.old", tmp); 
 
-	if (g_file_test (filename, G_FILE_TEST_ISDIR)) {
+	if (g_file_test (filename, G_FILE_TEST_IS_DIR)) {
 		nuke_backup (abs);
 	}
 	
@@ -665,6 +675,9 @@ load_categories (GnomePilotConduitStandardAbs *abs)
 	categories = g_hash_table_new (g_str_hash, g_str_equal);
 	filename = g_strdup_printf ("%s/.categories", GET_CONDUIT_CFG (abs)->dir);
 
+	if (!g_file_test (filename, G_FILE_TEST_EXISTS))
+		return categories;
+
 	if ((f = fopen (filename,"r"))==NULL) return NULL;
 	
 	while (fgets (category_dir, FILENAME_MAX-1, f)!=NULL) {
@@ -715,7 +728,7 @@ free_loadinfo_foreach (LoadInfo *info, gpointer whatever)
 }
 
 /** loads the records into the abs structure */
-static void 
+static gboolean
 load_records (GnomePilotConduitStandardAbs *abs) 
 {
 	FILE *idfile;
@@ -733,12 +746,12 @@ load_records (GnomePilotConduitStandardAbs *abs)
 
 	if ((dir=opendir (GET_CONDUIT_CFG (abs)->dir))==NULL) {
 		LOG ("load_records cannot open %s", GET_CONDUIT_CFG (abs)->dir);
-		return;
+		return FALSE;
 	}
 	if ((categories = load_categories (abs))==NULL) {
 		LOG ("no categories, no records");
 		closedir (dir);
-		return;
+		return FALSE;
 	}
 	while ((de=readdir (dir))) {
 		GHashTable *loadinfo;
@@ -846,6 +859,8 @@ load_records (GnomePilotConduitStandardAbs *abs)
 	gnome_pilot_conduit_standard_abs_set_num_deleted_local_records (abs, deleted);
 	
 	LOG ("records: total = %d updated = %d new = %d deleted = %d", total, updated, newrecs, deleted);
+
+	return TRUE;
 }
 
 
@@ -870,11 +885,12 @@ pre_sync (GnomePilotConduit *c, GnomePilotDBInfo *dbi)
 	unpack_MemoAppInfo (&(GET_CONDUIT_DATA (c)->ai), buf, l);
 	g_free (buf);
 
-	if (GET_CONDUIT_CFG (c)->dir==NULL) {
+	if (GET_CONDUIT_CFG (c)->dir==NULL || *(GET_CONDUIT_CFG (c)->dir) == '\0') {
 		return -1;
 	}
 
-	load_records ((GnomePilotConduitStandardAbs*)c); 
+	if (!load_records ((GnomePilotConduitStandardAbs*)c))
+		return -1;
 
 	/* If local store is empty force the slow sync. */
 	if (g_list_length (GET_CONDUIT_DATA (c)->records)==0){
@@ -1183,7 +1199,7 @@ insert_ignore_space (GtkEditable    *editable, const gchar    *text,
 		     gint len, gint *position, void *data)
 {
 	gint i;
-	gchar *curname;
+	const gchar *curname;
 
 	curname = gtk_entry_get_text (GTK_ENTRY (editable));
 	if (*curname == '\0' && len > 0) {
@@ -1325,7 +1341,7 @@ readOptionsCfg (GtkWidget *pilotcfg, ConduitCfg *state)
 	if (state->dir) g_free (state->dir);
 	state->dir = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
 
-	while (state->dir[strlen (state->dir)-1] == '/') {
+	while (state->dir && strlen (state->dir) > 0 && state->dir[strlen (state->dir)-1] == '/') {
 		state->dir[strlen (state->dir)-1] = '\0';
 	}
 
@@ -1427,7 +1443,7 @@ conduit_get_gpilot_conduit (guint32 pilotId)
 	gtk_signal_connect (retval, "save_settings", (GtkSignalFunc) save_settings, NULL);
 	gtk_signal_connect (retval, "revert_settings", (GtkSignalFunc) revert_settings, NULL);
 
-	load_configuration (&cfg, pilotId);
+	load_configuration (GNOME_PILOT_CONDUIT (retval), &cfg, pilotId);
 	cfg2 = dupe_configuration (cfg);
 	gtk_object_set_data (GTK_OBJECT (retval), OBJ_DATA_CONFIG, cfg);
 	gtk_object_set_data (GTK_OBJECT (retval), OBJ_DATA_OLDCONFIG, cfg2);
